#
# spec file for package python-pyproj
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyproj
Version:        3.6.1
Release:        1.1
Summary:        Python interface to PROJ library
License:        SUSE-Public-Domain AND X11
Group:          Development/Languages/Python
URL:            https://github.com/pyproj4/pyproj
Source:         https://files.pythonhosted.org/packages/source/p/pyproj/pyproj-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.28.4 with %python-Cython < 3}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  proj
BuildRequires:  proj-devel >= 8
BuildRequires:  python-rpm-macros
Requires:       python-certifi
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION test requirements
BuildRequires:  %{python_module Shapely}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xarray}
# /SECTION
%python_subpackages

%description
Performs cartographic transformations and geodetic computations.

The Proj class can convert from geographic (longitude,latitude) to native map
projection (x,y) coordinates and vice versa, or from one map projection
coordinate system directly to another.

The Geod class can perform forward and inverse geodetic, or Great Circle,
computations. The forward computation involves determining latitude, longitude
and back azimuth of a terminus point given the latitude and longitude of an
initial point, plus azimuth and distance. The inverse computation involves
determining the forward and back azimuths and distance given the latitudes and
longitudes of an initial and terminus point.

Input coordinates can be given as python arrays, lists/tuples, scalars or
numpy/Numeric/numarray arrays. Optimized for objects that support the Python
buffer protocol (regular python and numpy array objects).

This project has a git repository https://github.com/pyproj4/pyproj
where you may access the most up-to-date source.

%prep
%setup -q -n pyproj-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyproj
%python_expand rm -rf  %{buildroot}%{$python_sitearch}/test
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv pyproj pyproj_temp
export PROJ_DIR=$(pkg-config --variable=libdir proj)
%{python_expand # Multiline
export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -c "import pyproj; pyproj.Proj(init='epsg:4269')"
}
# Reset to remove wrong flavor path from loop above
export PYTHONPATH=""
%pytest_arch -rs -k "not (network or test_transformer_group__get_transform_crs)"
mv pyproj_temp pyproj

%post
%python_install_alternative pyproj

%postun
%python_uninstall_alternative pyproj

%files %{python_files}
%python_alternative %{_bindir}/pyproj
%license LICENSE
%doc README.md
%{python_sitearch}/pyproj
%{python_sitearch}/pyproj-%{version}*-info

%changelog
* Sun Sep 24 2023 Libor Pechacek <lpechacek@gmx.com>
- Update to 3.6.1
  * WHL: Update to PROJ 9.3 by @snowman2 in #1334
  * DEP: Add Python 3.12 support by @snowman2 in #1341
  * BUG: Cython 3 compatibility fixes by @snowman2 in #1322
  * BUG: Remove pkg_resources from setup.py by @snowman2 in #1314
  * DOC: Fixed typos by @djm93dev in #1305 & #1306
  * DOC: Fix logo view on Pypi by @cyschneck in #1308
  * DOC: Spelling permimeter -> perimeter by @zanejgr in #1310
* Tue Aug 29 2023 Ben Greiner <code@bnavigator.de>
- Limit to Cython <3 gh#pyproj4/pyproj#1321
- Use PEP517 macros instead of deprecated setup.py
- 15.X: give it a chance with the SLE15 python module pythons
  (would need more dependencies for it to build)
* Tue Jun 13 2023 Libor Pechacek <lpechacek@gmx.com>
- Update to 3.6.0
  * WHL: Wheels contain PROJ 9.2.1 by @snowman2 in #1291
  * DEP: Minimum supported Python version 3.9 by @snowman2
    in #1245
  * ENH: Add CRS.to_2d() by @rhugonnet in #1267
  * ENH: Added allow_superseded kwargs to TransformerGroup by
    @dmahr1 in #1269
  * ENH: Added parameter output_axis_rule to CRS.to_wkt by
    @jjimenezshaw in #1287
  * BUG: fix Geod.npts NaN handling by @snowman2 in #1288
  * MNT: Use pyproject.toml for project metadata by @snowman2
    in #1275
* Tue Mar 28 2023 Libor Pechacek <lpechacek@gmx.com>
- Update to 3.5.0
  * WHL: PROJ 9.2 in wheels in #1243
  * DEP: Minimum PROJ version 9.0 by @snowman2 in #1244
  * ENH: Add inplace kwarg to Geod.fwd and Geod.inv by @greglucas
    in #1201
  * ENH: Add return_back_azimuth kwarg to fwd, inv,
    fwd_intermediate, inv_intermediate by @idanmiara in #1165
  * ENH: Added only_best kwarg to Transformer.from_crs by
    @snowman2 in #1236
  * PERF: Optimize point transformations by @greglucas &
    @snowman2 in #1204, #1209, #1205
  * PERF: Optimize for single point in Geod fwd/inv functions by
    @greglucas in #1206
  * REF: Raise error when CRS.to_wkt, CRS.to_json, or
    CRS.to_proj4 returns None by @snowman2 in #1218
  * CLN: Remove AzumuthalEquidistantConversion &
    LambertAzumuthalEqualAreaConversion by @snowman2 in #1220
  * BUG: Fix Derived Projected CRS support by @snowman2 in #1222
  * BUG: Add horizontal_datum_name for geographic CRS in
    CRS.to_cf by @snowman2 in #1255
- Drop upstream patch:
  * 0001-TST-Update-test_transform_bounds__ignore_inf-for-PRO.patch
  * 0002-TST-Update-transformer-test_repr__conditional-1241.patch
* Tue Mar 21 2023 Libor Pechacek <lpechacek@gmx.com>
- Fix failing tests after Proj update to 9.2.0 (upstream #1224, #1241)
- Add upstream patch:
  * 0001-TST-Update-test_transform_bounds__ignore_inf-for-PRO.patch
  * 0002-TST-Update-transformer-test_repr__conditional-1241.patch
* Tue Mar 21 2023 John Vandenberg <jayvdb@gmail.com>
- Skip two tests to support latest PROJ 9.2
* Sun Mar 19 2023 Bruno Friedmann <bruno@ioda-net.ch>
- Disable python38 support due to new xarray version.
* Thu Dec 15 2022 Libor Pechacek <lpechacek@gmx.com>
- Update to 3.4.1
  * WHL: Add win32 to build_wheels matrix by @molinav in #1169
  * BUG: Changed so that the setup.cfg depends on the version
    code in the init.py by @Scoppio in #1156
  * REF: Use upper case EPSG code when creating CRS by @snowman2
    in #1162
  * BUG: Fix CRS.to_cf for Pole rotation GRIB convention by
    @snowman2 in #1167
  * BUG: Fix memory leak in CRS.list_authority by @skogler in
    [#1178]
  * BUG: Fix Transform options array length by @shadchin in #1187
  * DOC: fix a few typos by @ocefpaf in #1153
* Fri Sep 16 2022 John Vandenberg <jayvdb@gmail.com>
- Add mandatory runtime dep python-certifi, and remove not
  required dependency python-numpy
- Remove BD python-testsuite, and reduce tests skipped
* Sun Sep 11 2022 Libor Pechacek <lpechacek@gmx.com>
- Update to 3.4.0
  * DEP: Add python 3.11 support by @snowman2 in #1121
  * DEP: Minimum PROJ version 8.2 by @snowman2 in #1122
  * DEP: Update wheels with PROJ 9.1.0 by @snowman2 in #1132
  * ENH: Added authority, accuracy, and allow_ballpark kwargs to
    TransformerGroup by @snowman2 in #1076
  * ENH: Added force_over kwarg to Transformer.from_crs by
    @snowman2 in #1123
  * ENH: Added Transformer.get_last_used_operation by @snowman2
    in #1124
  * BUG: Fix transformer list for 3D transformations in
    TransformerGroup by @snowman2 in #1075
  * BUG: Mercator A defined only for lat_0 = 0 by @kdpenner in
    [#1095]
  * BUG: Add support for PROJ_DATA environment variable by
    @snowman2 in #1099
  * BUG: Ensure numpy masked arrays stay masked after projection
    by @paultcochrane in #1103
  * BLD: Don't specify runtime_library_dirs on Cygwin by @DWesl
    in #1120
  * BUG: Fix finding PROJ version with PROJ_LIB and PROJ 9.1+ by
    @snowman2 in #1128
  * CLN: Remove deprecated 'skip_equivalent' kwarg from
    transformers and 'errcheck' kwarg from CRS.from_cf by
    @snowman2 in #1077
  * REF: use regex to process PROJ strings in CRS.to_dict() by
    @snowman2 in #1086
  * DOC: Fix typo in installation docs by @paultcochrane in #1101
  * DOC: Fix issues in transformation grids docs by
    @paultcochrane in #1104
* Fri May  6 2022 Libor Pechacek <lpechacek@suse.com>
- Update to 3.3.1
  * DOC: minor fix to crs doc-strings by @bjlittle in #1004
  * BUG: Correct type annotation for AreaofUse.bounds by
    @Kirill888 in #1013
  * BUG: crs.py: remove @AbstractMethod decorator by @hemberger
    in #1018
  * BUG: Reorder deps in show_versions for setuptools issue by
    @snowman2 in #1019
  * BUG: get_data_dir support for conda Windows enviroments by
    @snowman2 in #1030
  * ENH: warn when export of CRS returns None by @martinfleis
    in #1037
  * BUG: Complete database stub file with query_utm_crs_info()
    signature by @orontee in #1047
  * ENH: Added support for int-like strings and numpy dtypes by
    @iboates in #1049
  * BUG: Warn when CRS cannot be converted to PROJ or PROJ JSON
    by @snowman2 in #1054
  * ENH: Added support to pickle Transformer by @snowman2
    in #1060
* Thu Nov 18 2021 Libor Pechacek <lpechacek@suse.com>
- Update to 3.3.0
  * WHL: Wheels contain PROJ 8.2.0
  * DEP: Minimum supported Python version 3.8 (issue #930)
  * DEP: Minimum PROJ version 8.0 (issue #940)
  * BUG: Prepend "Derived" to CRS type name if CRS is derived
    (issue #932)
  * BUG: Improved handling of inf values in
    pyproj.transformer.Transformer.transform_bounds (pull #961)
  * BUG: CRS CF conversions mismatch of PROJ parameters in
    rotated pole (issue #948)
  * ENH: Add support for transforming bounds at the poles in
    pyproj.transformer.Transformer.transform_bounds (pull #962)
  * ENH: Added pyproj.transformer.Transformer.source_crs &
    pyproj.transformer.Transformer.target_crs (pull #976)
  * ENH: Added
    pyproj.crs.coordinate_operation.PoleRotationNetCDFCFConversion
    (issue #948)
  * ENH: Added pyproj.database.get_database_metadata (issue #990)
  * ENH: Added PROJ database metadata to pyproj.show_versions
    (issue #990)
- Packaging: update build requirements
* Mon Sep 20 2021 Libor Pechacek <lpechacek@suse.com>
- Update to 3.2.1
  * REF: declare specific python types in cython (pull #928)
  * REF: Use cython string decoding (pull #929)
  * BUG: Return multiple authorities with
    pyproj.crs.CRS.list_authority (pull #943)
  * BUG: CRS CF conversions ensure lon_0 =
    north_pole_grid_longitude + 180 (issue #927)
  * BUG: CRS CF conversions ensure Pole rotation (netCDF CF
    convention) conversion works (issue #927)
* Mon Sep 13 2021 Libor Pechacek <lpechacek@suse.com>
- Update to 3.2.0
  * WHL: Wheels contain PROJ 8.1.1
  * DOC: Add new pyproj logo (issue #700)
  * REF: Handle deprecation of
    proj_context_set_autoclose_database (issue #866)
  * REF: Make CRS methods inheritable (issue #847)
  * ENH: Added pyproj.crs.CRS.is_derived (pull #902)
  * ENH: Added pyproj.crs.GeocentricCRS (pull #903)
  * ENH: Added pyproj.crs.CRS.list_authority (issue #918)
  * ENH: Added inplace kwarg to
    :meth:pyproj.transformer.Transformer.transform (issue #906)
  * PERF: Disable unnecessary copy in dtype conversion for buffer
    (pull #904)
  * DOC: Improve FAQ text about CRS formats (issue #789)
  * BUG: Add PyPy cython array implementation (issue #854)
  * BUG: Fix spelling for
    pyproj.crs.coordinate_operation.AzimuthalEquidistantConversion
    and pyproj.crs.coordinate_operation.LambertAzimuthalEqualAreaConversion
    (issue #882)
  * BUG: Make datum name match exact in
    pyproj.database.query_utm_crs_info (pull #887)
  * BUG: Update pyproj.enums.GeodIntermediateFlag for future
    Python compatibility (issue #855)
  * BUG: Hide unnecessary PROJ ERROR from
    proj_crs_get_coordoperation (issue #873)
  * BUG: Fix pickling for CRS builder classes (issue #897)
  * CLN: Remove ignore_axis_order kwarg from
    pyproj.crs.CRS.is_exact_same as it was added by accident
    (pull #904)
  * CLN: remove numeric/numarrays support (pull #908)
  * LNT: Add pylint & address issues (pull #909)
  * DEP: Remove distutils dependency (pull #917)
* Fri Jun 25 2021 Ben Greiner <code@bnavigator.de>
- Fix the python >= 3.7 build requirement
  * `BuildRequires: python` is a pure python2 specification now
  * no need for the full stdlib (`BuildRequires: %%pythons >= 3.7`)
* Thu May 27 2021 Libor Pechacek <lpechacek@suse.com>
- Refresh the source tarball from pythonhosted.org.
* Tue May 25 2021 Libor Pechacek <lpechacek@suse.com>
- Update to 3.1.0
  * DEP: Minimum supported Python version 3.7 (issue #790)
  * REF: Multithread safe CRS, Proj, & Transformer (issue #782)
  * BUG: Disallow NaN values with AreaOfInterest & BBox
    (issue #788)
  * ENH: Pretty format PROJ string support (issue #764)
  * ENH: Added pyproj.transformer.Transformer.to_proj4
    (pull #798)
  * ENH: Added authority, accuracy, and allow_ballpark kwargs to
    :meth:pyproj.transformer.Transformer.from_crs (issue #754)
  * ENH: Added support for "AUTH:CODE" input to
    :meth:pyproj.transformer.Transformer.from_pipeline
    (issue #755)
  * ENH: Added pyproj.crs.CRS.to_3d (pull #808)
  * ENH: Added pyproj.transformer.Transformer.transform_bounds
    (issue #809)
  * ENH: Added pyproj.crs.CRS.is_compound (pull #823)
  * ENH: Added initial_idx and terminal_index kwargs to
    pyproj.Geod.npts (pull #841)
  * ENH: Added pyproj.Geod.inv_intermediate &
    pyproj.Geod.fwd_intermediate (pull #841)
  * REF: Skip transformations if noop & deprecate skip_equivalent
    (pull #824)
* Fri Mar 19 2021 Libor Pechacek <lpechacek@suse.com>
- Update to 3.0.1:
  * WHL: Wheels contain PROJ 7.2.1
  * Use proj_context_errno_string in PROJ 8+ due to deprecation (issue #760)
  * BUG: Allow transformations with empty arrays (issue #766)
  * BUG: support numpy objects in CRS.from_cf (issue #773)
* Mon Feb 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable Python 3.6 as numpy is not available anymore for 3.6.
  See NEP29: https://numpy.org/neps/nep-0029-deprecation_policy.html
* Tue Feb  9 2021 Benjamin Greiner <code@bnavigator.de>
- Fix malformed Cython requirement
- Remove (malformed) unneeded coverage requirement and mock which
  is imported from unittest already.
- Actually install the alternative for the entrypoint
- Use the pytest_arch macro for the tests
* Tue Jan 19 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.0.0:
  * Minimum supported Python version 3.6 (issue #499)
  * Minimum PROJ version 7.2 (issues #599 & #689)
  * WHL: Removed datumgrids from wheels because not needed with RFC 4 (pull #628)
  * ENH: Added PROJ Network Settings (#675, #691, #695)
  * ENH: Added ability to use global context (issue #661)
  * ENH: Added transformation grid sync API/CLI (issue #572)
  * ENH: Support obects with __array__ method (pandas.Series, xarray.DataArray, dask.array.Array) (issue #573)
  * ENH: Added pyproj.datadir.get_user_data_dir() (pull #636)
  * ENH: Added pyproj.transformer.Transformer.is_network_enabled (issue #629)
  * ENH: Added pyproj.transformer.TransformerGroup.download_grids() (pull #643)
  * ENH: Use ‘proj_get_units_from_database’ in pyproj.database.get_units_map() & cleanup pyproj.database.get_codes() (issue #619)
  * ENH: Added support for radians for Proj & Transformer.from_pipeline & use less gil (issue #612)
  * ENH: Datum.from_name default to check all datum types (issue #606)
  * ENH: Use from_user_input in __eq__ when comparing CRS sub-classes (i.e. PrimeMeridian, Datum, Ellipsoid, etc.) (issue #606)
  * ENH: Add support for coordinate systems with CRS using CF conventions (issue #536)
  * ENH: Use proj_is_equivalent_to_with_ctx in the place of proj_is_equivalent_to internally (issue #666)
  * BUG: Add support for identifying engineering/parametric/temporal datums (issue #670)
  * ENH: Add support for temporal CRS CF coordinate system (issue #672)
  * ENH: Added support for debugging internal PROJ (pull #696)
  * ENH: Added pathlib support for data directory methods (pull #702)
  * ENH: Added pyproj.database.query_crs_info() (pull #703)
  * ENH: Added pyproj.database.query_utm_crs_info() (pull #712)
  * REF: Refactor Proj to inherit from Transformer (issue #624)
  * REF: Added pyproj.database, pyproj.aoi, and pyproj.list modules (pull #703)
  * BUG: Fix handling of polygon holes when calculating area in Geod (pull #686)
- Drop upstream patch:
  * pyproj-3.0.0-TST-Update-tests-with-scope-remarks-649.patch
- Include 'pyproj' command line tool
* Thu Sep 24 2020 Libor Pechacek <lpechacek@suse.com>
- Fix failing test after Proj update to 7.1.1
  - added patch pyproj-3.0.0-TST-Update-tests-with-scope-remarks-649.patch
* Tue May 19 2020 Libor Pechacek <lpechacek@suse.com>
- Update to 2.6.1.post1
  * WHL: Wheels contain PROJ version is 7.0.1
  * BUG: Allow *_name to be added in pyproj.crs.CRS.to_cf()
    (issue #585)
  * BUG: Fix building prime meridian in pyproj.crs.CRS.from_cf()
    (pull #588)
  * BUG: Fix check for numpy bool True kwarg (pull #590)
  * DOC: Update pyproj.Proj docstrings for clarity (issue #584)
  * Added pyproj.__proj_version__
  * BUG: Fix pyproj.proj.Proj.get_factors() (issue #600)
  * BUG: fix unequal (!=) with non-CRS type (pull #596)
* Thu Apr 23 2020 Martin Pluskal <mpluskal@suse.com>
- Simplify spec file
* Wed Mar 18 2020 Libor Pechacek <lpechacek@suse.com>
- Update to 2.6.0
  * ENH: Added pyproj.proj.Proj.get_factors (issue #503)
  * ENH: Added type hints (issue #369)
  * BUG: Don't use CRS classes for defaults in CRS child class init
    signatures (issue #554)
  * ENH: Updated :pyproj.crs.CRS.axis_info to pull all relevant axis
    information from CRS (issue #557)
  * ENH: Added pyproj.transformer.Transform.__eq__ (issue #559)
  * ENH: Added pyproj.crs.CRS.utm_zone (issue #561)
  * BUG: Modify CRS dict test to accomodate numpy bool types.
    (issue #564)
  * BUG: Fix pipeline transformations to match cct (issue #565)
  * BUG: Don't silently ignore kwargs when projparams are
    specified (Proj & CRS) (issue #565)
* Mon Feb 24 2020 Libor Pechacek <lpechacek@suse.com>
- Update to 2.5.0
  * Wheels contain PROJ version is 6.3.1
  * Remove deprecated PyObject_AsWriteBuffer (issue #495)
  * ENH: Added pyproj.crs.CRS.equals with ignore_axis_order kwarg
    (issue #493)
  * ENH: Added pyproj.crs.CoordinateSystem.from_json,
    pyproj.crs.CoordinateSystem.from_json_dict, and
    pyproj.crs.CoordinateSystem.from_string (pull #501)
  * ENH: Added pyproj.crs.CoordinateSystem to pyproj.crs
    namespace (pull #501)
  * ENH: Added pyproj.crs.CoordinateSystem.from_user_input,
    pyproj.crs.CoordinateOperation.from_user_input,
    pyproj.crs.Datum.from_user_input,
    pyproj.crs.PrimeMeridian.from_user_input,
    pyproj.crs.Ellipsoid.from_user_input (pull #502)
  * ENH: Added pyproj.crs.CoordinateSystem.from_name,
    pyproj.crs.CoordinateOperation.from_name,
    pyproj.crs.Datum.from_name,
    :meth:pyproj.crs.PrimeMeridian.from_name,
    pyproj.crs.Ellipsoid.from_name (pull #505)
  * BUG: Fix getting :attr:pyproj.crs.Ellipsoid.semi_minor_metre
    when not computed (issue #457)
  * ENH: Added support for custom CRS (issue #389)
  * ENH: Added enumeration for WKT2_2019 (issue #526)
  * ENH: Update from_cf/to_cf to use WKT instead of PROJ strings
    for internal management (issue #515)
* Mon Dec  2 2019 Libor Pechacek <lpechacek@suse.com>
- Update to 2.4.2.post1
  * Elevate +init= warning to FutureWarning (pull #486)
  * Add UserWarning to to_proj4() (pull #486)
  * BUG: Fix for 32-bit i686 plaforms (issue #481)
  * Return ‘inf’ in Proj instead of 1.e30 (pull #491)
* Wed Nov  6 2019 Libor Pechacek <lpechacek@suse.com>
- Update to 2.4.1
  * Wheels contain PROJ version is 6.2.1 (issue #456)
  * Wheels for Linux x86_64 use manylinux2010
    (pyproj4/pyproj-wheels/pull/18)
  * BUG: Fix setting lat_ts for mercator projection in
    CRS.from_cf() and CRS.to_cf() (issue #461)
  * BUG: latlon -> longlat in CRS.from_cf() for o_proj so
    behavior consistent in PROJ 6.2.0 and 6.2.1 (pull #472)
  * ENH: Add repr for pyproj.crs.CoordinateOperation and for
    pyproj.transformer.TransformerGroup (pull #464)
* Mon Nov  4 2019 Libor Pechacek <lpechacek@suse.com>
- Packaging: build only for Python 3 (requirement since v2.2.3), update package
  description and upstream URL, require Shapely, require PROJ >= 6.2.0
- Update to 2.4.0
  * Minimum PROJ version is 6.2.0 (issue #411)
  * Removed global pyproj context (issue #418)
  * Added support for PROJ JSON in pyproj.crs objects and pyproj.Transformer
    (pull #432)
  * Moved doctests code out of pyproj.__init__ (issue #417)
  * Added version information to python -m pyproj (pull #429)
  * Added scope & remarks to pyproj.crs objects and pyproj.Transformer
    (issue #441)
  * Added operations to pyproj.crs.CoordinateOperation objects and
    pyproj.Transformer (issue #441)
  * Added pyproj.get_authorities() and pyproj.get_codes() (issue #440)
  * Release gil in core cython/PROJ code (issue #386)
  * BUG: Added checks for unititialized pyproj.crs objects to prevent core
    dumping (issue #433)
  * BUG: Added fix for get_transform_crs when checking type (pull #439)
  * DOC: Build docs with python3 (pull #428)
- Update to 2.3.1
  * Added cleanup for internal PROJ errors (issue #184)
  * Delay checking for pyproj data directory until importing pyproj (issue #415)
  * Address issue where PROJ core dumps on proj_create with +init= when global
    context does not have data directory set (issue #415 & issue #368)
- Update to 2.2.3
  * Minimum supported Python version 3.5 (issue #331)
  + New pyproj.geod.Geod additions:
  * Added support for calculating geodesic area
    (Geod.polygon_area_perimeter())
  * and added interface to calculate total length of a line
  * (Geod.line_length() & Geod.line_lengths()) (issue #210).
  * Added support for calculating geodesic area and line lemgths with
    shapely geometries (Geod.geometry_area_perimeter() &
    Geod.geometry_length()) (pull #366)
  + New pyproj.transformer additions:
  * Added pyproj.transformer.TransformerGroup to make all transformations
    available (issue #381)
  * Added option for area_of_interest for Transformer.from_crs(),
  * Transformer.from_proj() and pyproj.transformer.TransformerGroup
  * Added Transformer.area_of_use (issue #385)
  * Added pyproj.crs.CoordinateOperation.area_of_use (issue #385)
  * Updated to only have one PJ_CONTEXT per pyproj session (issue #374)
  * Always return latlon with Proj (issue #356)
  * Remove aenum dependency (issue #339)
  * Removed deprecated functions/properties Proj.proj_version, CRS.is_valid,
    and CRS.to_geodetic() (pull #371)
  * Search on sys.prefix for the PROJ data directory (issue #387)
- Update to 2.2.2
  * Update wheels to PROJ 6.1.1
  * Add deprecation warning when using +init= syntax (pull #358)
  * Added pyproj.crs.is_proj() (pull #359)
  * Fixed case in CRS.to_dict() with CRS.to_proj4() returning None (pull #359)
  * Keep no_defs in input PROJ string as it does not hurt/help anything in
    current code (pull #359)
  * Made public properties on C classes readonly (pull #359)
  * Update data dir exception handling to prevent ignoring errors (pull #361)
  * CRS.to_cf() export transverse mercator parameters for UTM zones (pull #362)
- Update to 2.2.1
  * Added pyproj.show_versions() (issue #334)
  * Added fix for whitepace around ‘=’ in PROJ strings (issue #345)
  * Update version check in setup.py (issue #323)
  * Add “stable” doc site pointing to latest release (issue #347, pull #348)
  * Depreate Proj.proj_version (pull #337)
  * Test fixes (pull #333, pull #335)
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.2.0
  * Minimum PROJ version is now 6.1.0
  + `pyproj.crs` updates:
  * Updated CRS repr (issue #264)
  * Add Datum, CoordinateSystem, CoordinateOperation clases (issue #262)
  * Added :meth:`~pyproj.crs.CRS.to_cf` and :meth:`~pyproj.crs.CRS.from_cf` for
    converting to/from Climate and Forcast (CF) 1.8 grid mappings (pull #244)
  * Added :meth:`~pyproj.crs.CRS.to_dict` (issue #226)
  * Added :meth:`~pyproj.crs.CRS.to_authority` (pull #294)
  * Added :attr:`~pyproj.crs.CRS.is_vertical` and :attr:`~pyproj.crs.CRS.is_engineering` (issue #316)
  * Added :attr:`~pyproj.crs.CRS.target_crs` (pull #328)
  * Provide option to "pretty print" WKT in :attr:`~pyproj.crs.CRS.to_wkt` (issue #258)
  * Add support for Bound and Compound CRS for :attr:`~pyproj.crs.CRS.is_geographic`, :attr:`~pyproj.crs.CRS.is_projected` (issue #274)
  * Add support for Bound CRS for :attr:`~pyproj.crs.CRS.is_geocentric` (issue #374)
  * Add support for comparison with CRS a non-crs type supported by :meth:`~pyproj.crs.CRS.from_user_input` (issue #312)
  * Added support for ITRF, compound EPSG, and urn projection strings in CRS (pull #289)
  * Better handle Compound CRS (issue #265)
  * Disallow creation of non-CRS object (eg pipeline) in CRS class (issue #267)
  * Added check in :meth:`~pyproj.crs.CRS.to_epsg` for when `proj_list` is null (issue #257)
  * Fix comparing classes of non-instance types (issue #310)
  +  `pyroj.transformer` updates:
  * Added `always_xy` option to Transformer so the transform method will
    always accept as input and return as output coordinates using the
    traditional GIS order, that is longitude, latitudecfor geographic
    CRS and easting, northing for most projected CRS (issue #225)
  * Provide `direction` option in :meth:`~pyproj.transformer.Transformer.transform` (issue #266)
  * Add check for valid initialization of Transformer and ensure it is a transformer (issue #321)
  * Added :meth:`~pyproj.transformer.Transformer.to_wkt` as well as attributes related to `PJ_PROJ_INFO` (pull #322)
  * Undo deprecation of :meth:`~pyproj.transformer.Transformer.from_crs` (issue #275)
  * Fix false positive errors raised in transformer (issue #249)
  * Fix :class:`~pyproj.proj.Proj` initialization from DerivedGeographicCRS (issue #270)
  * Add interface to get the projection/ellps/prime_meridian/units lists (issue #251)
  * Docs/Build/Test fixes (pull #278, pull #245, pull #248, pull #247, issue #253, pull #252)
- Update to 2.1.3
  * Added support for time transformations (issue #208)
  * Fixed projection equivalence testing for transformations (pull #231).
  * Switch to pytest for testing (pull #230)
  * Various testing fixes (pull #223, #222, #221, #220)
  * Convert PROJ error messages from bytes to strings (pull #219)
  * Fix data dir path separator to be (;) for windows and (:) for linux (pull #234)
- Update to 2.1.2
  * Updated to use the CRS definition for Proj instances in transforms (issue #207)
  * Add option to skip tranformation operation if input and output projections are equivalent
    and always skip if the input and output projections are exact (issue #128)
  * Update setup.py method for checking PROJ version (pull #211)
  * Add internal proj error log messages to exceptions (pull #215)
- Update to 2.1.1
  * Restore behavior of 1.9.6 when illegal projection transformation requested
    (return ``inf`` instead of raising an exception, issue #202).  kwarg ``errcheck``
    added to :func:`~pyproj.transformer.transform` and :func:`~pyproj.transformer.itransform`
    (default ``False``). When ``errcheck=True`` an exception is raised.
- Update to 2.1.0
  * Added :class:`~pyproj.transformer.Transformer` to make repetitive transformations more efficient (issue #187)
  * Added fix for using local datumgrids with transform (issue #191)
  * Added :meth:`~pyproj.transformer.Transformer.from_pipeline` to support pipeline transformations.
  * Added fix for conversion between radians/degrees for transformations (issues #192 & #195)
- Update to 2.0.2
  * add filter for boolean values in dict2string so "no_rot=True" works (issue #183).
  * make sure .pxd files included in source tarball.
  * add radians flag back in for transform/itransform (issue #185).
- Run unit tests
- Fix dependencies
* Mon Mar 11 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0.1:
  * Ensure data path set properly for TransProj (pull request #179,
    addressed issue #176).
- Changes for version 2.0.0:
  * Update to PROJ.4 version 6.0.0 & removed support for older
    PROJ.4 versions.
  * Added pyproj.CRS class.
  * Updated pyproj.Proj & pyproj.transform to accept any input
    from CRS.from_user_input.
  * Removed internal PROJ.4 source code.
  * Changed default for preserve_units to be True in pyproj.Proj
    class initialization.
  * Modified logic for searching for the PROJ.4 data directory to
    not conflict with older versions of PROJ.4.
  * Added pyproject.toml.
- Temporarily disable tests
* Tue Feb  5 2019 Bruno Friedmann <bruno@ioda-net.ch>
- update to 1.9.6 (python3.7 support)
- spec-cleaner minimal
* Tue May 15 2018 bruno@ioda-net.ch
- Packaging :
  + move to python singlespec
  + use %%check and run unit tests for version >= 1500
  + spec-cleaner (date/license)
- update upstream release 1.9.5.1
  * fix for issue #42 compilation error with microsoft visual studio
  + 1.9.5
  * update proj4 source to latest github master commit 953cc00f
  * port of basemap fix for input arrays in fortran order
  * restore inverse Hammer patch that was lost when proj4 source
    code was updated.
* Fri Oct 23 2015 bruno@ioda-net.ch
- Packaging : merged package to python-pyproj src in App:Geo
* Wed Oct 21 2015 bruno@ioda-net.ch
- update upstream release 1.9.4
  + 1.9.4 (git tag v1.9.4rel)
  * migrate to github from googlecode.
  * update proj4 source code from svn r2595 (version 4.9.0RC2).
  * include runtime_library_dirs in setup-proj.py.
  * added to_latlong method (issue 51).
  * fix back azimuth when lon1 and lon2 are identical.
  + 1.9.3 (svn revision 327)
  * Geod now uses C code adapted from geographiclib now included
  in proj4 source,  instead of pure python code directly from
    geographiclib.
  * make radians=True work with Geod.npts (issue 47).
  * allow PROJ_DIR env var to control location of proj data
    (issue 40).
  + 1.9.2 (svn revision 301)
  * updated proj4 src to 4.8.0 - includes two new map
    projections (natearth and isea).
  + 1.9.1 (svn revision 285)
  * restore compatibility with python 2.4/2.5, which was broken
    by the addition of the geographiclib geodesic
    module (issue 36).
- packaging
  + create equivalent python3 package
  + cleanup spec format
* Sat Feb 11 2012 ocefpaf@gmail.com
- first openSuse release 1.9.0
